%global momorel 3
%global tarball_ver 1_39_0
%global sonamever 5

Name: boost
Summary: The Boost C++ Libraries
Version: 1.39.0
Release: %{momorel}m%{?dist}
License: "Boost Software License"
URL: http://www.boost.org/
Group: System Environment/Libraries
Source0: http://dl.sourceforge.net/sourceforge/boost/boost_%{tarball_ver}.tar.bz2
NoSource: 0
Obsoletes: boost-doc < 1.39.0
Obsoletes: boost-python < 1.39.0
Provides: boost-python

# boost is an "umbrella" package that pulls in all other boost components
Requires: boost-date-time = %{version}-%{release}
Requires: boost-filesystem = %{version}-%{release}
Requires: boost-graph = %{version}-%{release}
Requires: boost-iostreams = %{version}-%{release}
Requires: boost-math = %{version}-%{release}
Requires: boost-test = %{version}-%{release}
Requires: boost-program-options = %{version}-%{release}
Requires: boost-python = %{version}-%{release}
Requires: boost-regex = %{version}-%{release}
Requires: boost-serialization = %{version}-%{release}
Requires: boost-signals = %{version}-%{release}
Requires: boost-system = %{version}-%{release}
Requires: boost-wave = %{version}-%{release}

%{?include_specopt}
#  If you'd like to change these configurations, please copy them to
# ~/rpmbuild/specopt/boost.specopt and edit it.
%{?!do_test: %global do_test 0}
%{?!rebuild_docs: %global rebuild_docs 0}

Patch0: boost-version-override.patch
Patch1: boost-use-rpm-optflags.patch
Patch2: boost-run-tests.patch
Patch3: boost-soname.patch
Patch4: boost-unneccessary_iostreams.patch
Patch5: boost-bitset.patch
Patch6: boost-function_template.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python 
BuildRequires: boost-jam >= 3.1.14-2m
BuildRequires: gcc-c++ >= 3.4.1-1m
BuildRequires: libstdc++-devel
BuildRequires: zlib-devel
BuildRequires: bzip2-devel
BuildRequires: python-devel
BuildRequires: libicu-devel >= 4.0
BuildRequires: chrpath

%description
Boost provides free peer-reviewed portable C++ source libraries.  The
emphasis is on libraries which work well with the C++ Standard
Library.  One goal is to establish "existing practice" and provide
reference implementations so that the Boost libraries are suitable for
eventual standardization. (Some of the libraries have already been
proposed for inclusion in the C++ Standards Committee's upcoming C++
Standard Library Technical Report.)

%package date-time
Summary: Runtime component of boost date-time library
Group: System Environment/Libraries

%description date-time

Runtime support for Boost Date Time, set of date-time libraries based
on generic programming concepts.

%package filesystem
Summary: Runtime component of boost filesystem library
Group: System Environment/Libraries

%description filesystem

Runtime support for the Boost Filesystem Library, which provides
portable facilities to query and manipulate paths, files, and
directories.

%package graph
Summary: Runtime component of boost graph library
Group: System Environment/Libraries

%description graph

Runtime support for the BGL graph library.  BGL interface and graph
components are generic, in the same sense as the the Standard Template
Library (STL).

%package iostreams
Summary: Runtime component of boost iostreams library
Group: System Environment/Libraries

%description iostreams

Runtime support for Boost.IOStreams, a framework for defining streams,
stream buffers and i/o filters.

%package math
Summary: Runtime component of boost math library
Group: System Environment/Libraries

%description math

Runtime support Boost.Math, a library of math and numeric tools.

%package test
Summary: Runtime component of boost test library
Group: System Environment/Libraries

%description test

Runtime support for simple program testing, full unit testing, and for
program execution monitoring.

%package program-options
Summary:  Runtime component of boost program_options library
Group: System Environment/Libraries

%description program-options

Runtime support of boost program options library, which allows program
developers to obtain (name, value) pairs from the user, via
conventional methods such as command line and config file.

%package python
Summary: Runtime component of boost python library
Group: System Environment/Libraries

%description python

The Boost Python Library is a framework for interfacing Python and
C++. It allows you to quickly and seamlessly expose C++ classes
functions and objects to Python, and vice-versa, using no special
tools -- just your C++ compiler.  This package contains runtime
support for Boost Python Library.

%package regex
Summary: Runtime component of boost regular expression library
Group: System Environment/Libraries

%description regex

Runtime support for boost regular expression library.

%package serialization
Summary: Runtime component of boost serialization library
Group: System Environment/Libraries

%description serialization

Runtime support for serialization for persistence and marshalling.

%package signals
Summary: Runtime component of boost signals and slots library
Group: System Environment/Libraries

%description signals

Runtime support for managed signals & slots callback implementation.

%package system
Summary: Runtime component of boost system support library
Group: System Environment/Libraries

%description system

Runtime component of Boost operating system support library, including
the diagnostics support that will be part of the C++0x standard
library.

%package wave
Summary: Runtime component of boost C99/C++ preprocessing library
Group: System Environment/Libraries

%description wave

Runtime support for the Boost.Wave library, a Standards conformant,
and highly configurable implementation of the mandated C99/C++
preprocessor functionality.

%package devel
Summary: The Boost C++ headers and shared development libraries
Group: Development/Libraries
Requires: boost = %{version}-%{release}
Provides: boost-python-devel = %{version}-%{release}

%description devel
Headers and shared object symlinks for the Boost C++ libraries.

%package static
Summary: The Boost C++ static development libraries
Group: Development/Libraries
Requires: boost-devel = %{version}-%{release}
Obsoletes: boost-devel-static < 1.39.0
Provides: boost-devel-static = %{version}-%{release}

%description static
Static libraries for the Boost C++ libraries.

%package doc
Summary: The Boost C++ html docs
Group: Documentation
Provides: boost-python-docs = %{version}-%{release}

%description doc
HTML documentation files for Boost C++ libraries.

%prep
%setup -q -n %{name}_%{tarball_ver}
%patch0 -p0
sed 's/_FEDORA_OPT_FLAGS/%{optflags}/' %{PATCH1} | %{__patch} -p0 --fuzz=0
%patch2 -p0
sed 's/_FEDORA_SONAME/%{sonamever}/' %{PATCH3} | %{__patch} -p0 --fuzz=0
%patch4 -p0
%patch5 -p0
%patch6 -p0

%build
BOOST_ROOT=`pwd`
export BOOST_ROOT

#(cd tools/jam/src && ./build.sh)
#BJAM=`find tools/jam/src/ -name bjam -a -type f`
BJAM=/usr/bin/bjam

CONFIGURE_FLAGS="--with-toolset=gcc"
PYTHON_VERSION=$(python -c 'import sys; print sys.version[:3]')
PYTHON_FLAGS="--with-python-root=/usr --with-python-version=$PYTHON_VERSION"
REGEX_FLAGS="--with-icu"
./bootstrap.sh $CONFIGURE_FLAGS $PYTHON_FLAGS $REGEX_FLAGS 

BUILD_VARIANTS="variant=release threading=single,multi debug-symbols=on"
BUILD_FLAGS="-d2 --layout=system $BUILD_VARIANTS"
$BJAM $BUILD_FLAGS %{?_smp_mflags} stage 

# rebuild docs, requires a network connection for docbook XSLT stylesheets
%if %{rebuild_docs}
cd ./doc
chmod +x ../tools/boostbook/setup_boostbook.sh
../tools/boostbook/setup_boostbook.sh
USER_CFG=$BOOST_ROOT/tools/build/v2/user-config.jam
$BOOST_ROOT/$BJAM --v2 -sICU_PATH=/usr --user-config=$USER_CFG html
cd ..
%endif

%check
%if %{do_test}
sh ./tools/regression/src/run_tests.sh
%endif

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_docdir}/boost-%{version}

# install lib
for i in `find stage -type f -name \*.a`; do
  NAME=`basename $i`;
  install -p -m 0644 $i %{buildroot}%{_libdir}/$NAME;
done;
for i in `find stage -type f -name \*.so`; do
  NAME=$i;
  SONAME=$i.%{sonamever};
  VNAME=$i.%{version};
  base=`basename $i`;
  NAMEbase=$base;
  SONAMEbase=$base.%{sonamever};
  VNAMEbase=$base.%{version};
  mv $i $VNAME;

  # remove rpath
  chrpath --delete $VNAME;

  ln -s $VNAMEbase $SONAME;
  ln -s $VNAMEbase $NAME;
  install -p -m 755 $VNAME %{buildroot}%{_libdir}/$VNAMEbase; 

  mv $SONAME %{buildroot}%{_libdir}/$SONAMEbase;
  mv $NAME %{buildroot}%{_libdir}/$NAMEbase;
done;

# install include files
find %{name} -type d | while read a; do
  mkdir -p %{buildroot}%{_includedir}/$a
  find $a -mindepth 1 -maxdepth 1 -type f \
  | xargs -r install -m 644 -p -t %{buildroot}%{_includedir}/$a
done

# install doc files
DOCPATH=%{buildroot}%{_docdir}/%{name}-%{version}/
find libs doc more -type f \( -name \*.htm -o -name \*.html \) \
    | sed -n '/\//{s,/[^/]*$,,;p}' \
    | sort -u > tmp-doc-directories
sed "s:^:$DOCPATH:" tmp-doc-directories | xargs -r mkdir -p
cat tmp-doc-directories | while read a; do
    find $a -mindepth 1 -maxdepth 1 -name \*.htm\* \
    | xargs install -m 644 -p -t $DOCPATH$a
done
rm tmp-doc-directories
install -p -m 644 -t $DOCPATH LICENSE_1_0.txt index.htm

# remove scripts used to generate include files
find %{buildroot}%{_includedir}/ \( -name '*.pl' -o -name '*.sh' \) -exec rm {} \;

%clean
rm -rf %{buildroot} 

%post 
/sbin/ldconfig

%postun 
/sbin/ldconfig

%files
%defattr(-, root, root, -)
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{sonamever}
%exclude %{_libdir}/libboost_date_time*.so.%{version}
%exclude %{_libdir}/libboost_date_time*.so.%{sonamever}
%exclude %{_libdir}/libboost_filesystem*.so.%{version}
%exclude %{_libdir}/libboost_filesystem*.so.%{sonamever}
%exclude %{_libdir}/libboost_graph*.so.%{version}
%exclude %{_libdir}/libboost_graph*.so.%{sonamever}
%exclude %{_libdir}/libboost_iostreams*.so.%{version}
%exclude %{_libdir}/libboost_iostreams*.so.%{sonamever}
%exclude %{_libdir}/libboost_math*.so.%{version}
%exclude %{_libdir}/libboost_math*.so.%{sonamever}
%exclude %{_libdir}/libboost_prg_exec_monitor*.so.%{version}
%exclude %{_libdir}/libboost_prg_exec_monitor*.so.%{sonamever}
%exclude %{_libdir}/libboost_unit_test_framework*.so.%{version}
%exclude %{_libdir}/libboost_unit_test_framework*.so.%{sonamever}
%exclude %{_libdir}/libboost_program_options*.so.%{version}
%exclude %{_libdir}/libboost_program_options*.so.%{sonamever}
%exclude %{_libdir}/libboost_python*.so.%{version}
%exclude %{_libdir}/libboost_python*.so.%{sonamever}
%exclude %{_libdir}/libboost_regex*.so.%{version}
%exclude %{_libdir}/libboost_regex*.so.%{sonamever}
%exclude %{_libdir}/libboost_serialization*.so.%{version}
%exclude %{_libdir}/libboost_serialization*.so.%{sonamever}
%exclude %{_libdir}/libboost_wserialization*.so.%{version}
%exclude %{_libdir}/libboost_wserialization*.so.%{sonamever}
%exclude %{_libdir}/libboost_signals*.so.%{version}
%exclude %{_libdir}/libboost_signals*.so.%{sonamever}
%exclude %{_libdir}/libboost_system*.so.%{version}
%exclude %{_libdir}/libboost_system*.so.%{sonamever}
%exclude %{_libdir}/libboost_wave*.so.%{version}
%exclude %{_libdir}/libboost_wave*.so.%{sonamever}

%files date-time
%defattr(-, root, root, -)
%{_libdir}/libboost_date_time*.so.%{version}
%{_libdir}/libboost_date_time*.so.%{sonamever}

%files filesystem
%defattr(-, root, root, -)
%{_libdir}/libboost_filesystem*.so.%{version}
%{_libdir}/libboost_filesystem*.so.%{sonamever}

%files graph
%defattr(-, root, root, -)
%{_libdir}/libboost_graph*.so.%{version}
%{_libdir}/libboost_graph*.so.%{sonamever}

%files iostreams
%defattr(-, root, root, -)
%{_libdir}/libboost_iostreams*.so.%{version}
%{_libdir}/libboost_iostreams*.so.%{sonamever}

%files math
%defattr(-, root, root, -)
%{_libdir}/libboost_math*.so.%{version}
%{_libdir}/libboost_math*.so.%{sonamever}

%files test
%defattr(-, root, root, -)
%{_libdir}/libboost_prg_exec_monitor*.so.%{version}
%{_libdir}/libboost_prg_exec_monitor*.so.%{sonamever}
%{_libdir}/libboost_unit_test_framework*.so.%{version}
%{_libdir}/libboost_unit_test_framework*.so.%{sonamever}

%files program-options
%defattr(-, root, root, -)
%{_libdir}/libboost_program_options*.so.%{version}
%{_libdir}/libboost_program_options*.so.%{sonamever}

%files python
%defattr(-, root, root, -)
%{_libdir}/libboost_python*.so.%{version}
%{_libdir}/libboost_python*.so.%{sonamever}

%files regex
%defattr(-, root, root, -)
%{_libdir}/libboost_regex*.so.%{version}
%{_libdir}/libboost_regex*.so.%{sonamever}

%files serialization
%defattr(-, root, root, -)
%{_libdir}/libboost_serialization*.so.%{version}
%{_libdir}/libboost_serialization*.so.%{sonamever}
%{_libdir}/libboost_wserialization*.so.%{version}
%{_libdir}/libboost_wserialization*.so.%{sonamever}

%files signals
%defattr(-, root, root, -)
%{_libdir}/libboost_signals*.so.%{version}
%{_libdir}/libboost_signals*.so.%{sonamever}

%files system
%defattr(-, root, root, -)
%{_libdir}/libboost_system*.so.%{version}
%{_libdir}/libboost_system*.so.%{sonamever}

%files wave
%defattr(-, root, root, -)
%{_libdir}/libboost_wave*.so.%{version}
%{_libdir}/libboost_wave*.so.%{sonamever}

%files doc
%defattr(-, root, root, -)
%doc %{_docdir}/%{name}-%{version}

%files devel
%defattr(-, root, root, -)
%{_includedir}/boost
%{_libdir}/*.so

%files static
%defattr(-, root, root, -)
%{_libdir}/*.a

%changelog
* Fri May 29 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.39.0-3m)
- re-apply function template compilation patch (Patch6)

* Tue May 19 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.39.0-2m)
- remove duplicate libraries

* Sun May 17 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.39.0-1m)
- update to 1.39.0 (copy from TSUPPA4RI/boost r32994)
- import a lot of changes from fc-devel (boost-1_39_0-1_fc12) 
-- now SONAME is 5
-- add boost-static sub package

* Wed May  6 2009 YAMAZAKI Makoto <zaki@zakky.org>
- (1.37.0-5m)
- added BuildPreReq: chrpath

* Sun Mar 29 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.37.0-4m)
- apply constant-expression patch from Rawhide (1.37.0-6)
-- https://bugzilla.redhat.com/show_bug.cgi?id=491537

* Sun Feb  1 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.37.0-3m)
- apply fix function template compilation patch (Patch6)
-- https://svn.boost.org/trac/boost/ticket/2499

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.37.0-2m)
- rebuild against rpm-4.6

* Thu Jan 15 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.37.0-1m)
- update to 1.37.0
-- update SONAME to 4
-- update Patch0 from Rawhide (1.37.0-2)
-- drop Patch2 which does not work well, instead use sed script
-- fix Patch3 where set proper boost_root
-- drop Patch4, merged upstream
-- drop Patch10, resolved at https://svn.boost.org/trac/boost/changeset/39240

* Sun Jul  6 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-9m)
- rebuild against icu-4.0

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.34.1-8m)
- rebuild against gcc43

* Fri Feb 22 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-7m)
- update boost-gcc43.patch

* Sun Feb 17 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.34.1-6m)
- rebuild against icu-3.8.1

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-5m)
- %%NoSource -> NoSource

* Thu Feb  7 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-4m)
- import two patches from fc-devel

* Sun Jan  6 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.34.1-3m)
- fixed criticul bug fix.
-- http://svn.boost.org/trac/boost/ticket/1260

* Mon Oct 29 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-2m)
- fixed regression tests failure with gcc-4.2
- build and regression tests now use installed /usr/bin/bjam

* Mon Aug 13 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (1.34.1-1m)
- update to 1.34.1
- merge a lot of changes between fc-devel's boost-1_33_1-6 and boost-1_34_1-3_fc8
-- update SONAME to 3 due to ABI changes
-- add devel-static package for .a libs
-- add regression tests

* Sun Jan  7 2007 Dai OKUYAMA <dai@ouchi.nahi.to>
- (1.33.1-3m)
- build fix with python 2.5

* Thu Oct 12 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.33.1-2m)
- sync FC
-  revised Patch1: boost-gcc-tools.patch
-  add Patch2 boost-thread.patch
-  add Patch3 boost-config-compiler-gcc.patch
-  add Patch4 boost-runtests.patch

* Tue Apr 18 2006 Masayuki SANO
- (1.33.1-1m)
- update to 1.33.1

* Wed Mar  9 2005 Toru Hoshina <t@momonga-linux.org>
- (1.32.0-1m)
- ver up.

* Sun Aug 22 2004 Hiroyuki Koga <kuma@momonga-linux.org>
- (1.31.0-1m)
- update to 1.31.0 (rebuild against gcc-c++-3.4.1)

* Fri May 14 2004 Masahiro Takahata <takahata@momonga-linux.org>
- (1.30.2-4m)
- change URI

* Sun Dec  7 2003 Ryu SASAOKA <ryu@momonga-linux.org>
- (1.30.2-3m)
- adapt the License: preamble for the Momonga Linux license
  expression unification policy (draft)

* Wed Oct 22 2003 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.30.2-2m)
- kill %%define version
- kill %%define release

* Mon Oct 20 2003 Hideo TASHIRO <tashiron@jasmiso.org>
- (1.30.2-1m)
- update to 1.30.2
- change License from "Freeware" to "Distributable"

* Tue Jun 10 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.30.0-1m)
- initial version for momonga (imported from rawhide)

* Tue May  6 2003 Tim Powers <timp@redhat.com> 1.30.0-3
- add deffattr's so we don't have unknown users owning files
